function X = teppich(i, plotflag);

% X = TEPPICH(i, plotflag) draws the i-th iteration of the
% Sierpinski carpet

if nargin < 1
    error(['At least one input arguments are required. Please type ' ...
        '''help teppich'' for usage information.']);
end

if nargin < 2
    plotflag = 0;
end

M = 0;
% create a matrix M consisting of zeros and ones
% indicating the points of the carpet
for k=1:i
    M = [M,        M,      M;
        M, ones(3^(k-1)), M;
        M,        M,      M];
end

X = [0 0];

N = size(M,1);

for j=1:N
    for k=1:N
        if M(j,k)==1
            X(end+1, :) = [j k];
        end
    end
end

if plotflag==1
    % plot settings
    hold on;
    imagesc(M);
    colormap(gray);
    axis equal; axis off;
    set(gca,'FontSize',14);
    set(gcf,'Color',[1,1,1]);
    title('The Sierpinski Carpet');
    hold off;
end